Package: redatamx
Title: R Interface to 'Redatam' Library
Version: 1.3.0
Authors@R: c(
    person(
      given = "Jaime", 
      family = "Salvador", 
      email = "jaime.salvador@ideasybits.com", 
      role = c("aut", "cre"),
      comment = c(ORCID = "0000-0002-3564-8929")),
    person(
      given = "CELADE",
      role = c("cph")
    )
  )
Maintainer: Jaime Salvador <jaime.salvador@ideasybits.com>
Description: Provides an API to work with 'Redatam' (see <https://redatam.org>) 
  databases in both formats: 'RXDB' (new format) and 'DICX' (old format) and running 
  'Redatam' programs written in 'SPC' language. It's a wrapper around 'Redatam' 
  core and provides functions to open/close a database (redatam_open()/redatam_close()), 
  list entities and variables from the database (redatam_entities(), redatam_variables()) 
  and execute a 'SPC' program and gets the results as data frames 
  (redatam_query(), redatam_run()).
License: GPL (>= 3)
Encoding: UTF-8
Language: en-US
RoxygenNote: 7.3.3
NeedsCompilation: yes
LinkingTo: cpp11
SystemRequirements: 'Redatam' runtime engine (see https://redatam.org),
        The dynamic binary library is downloaded from
        <https://redatam-core.s3.us-west-2.amazonaws.com> during the
        build step. Currently supported platforms are Windows, Linux
        and macOS.
Copyright: See COPYRIGHTS for details.
URL: https://ideasybits.github.io/redatamx4r/,
        https://github.com/ideasybits/redatamx4r/
BugReports: https://github.com/ideasybits/redatamx4r/issues
Config/Needs/website: rmarkdown
Packaged: 2026-05-05 21:39:24 UTC; jsalvador
Author: Jaime Salvador [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-3564-8929>),
  CELADE [cph]
Repository: CRAN
Date/Publication: 2026-05-06 05:10:02 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-05-06 06:59:33 UTC; unix
Archs: redatamx.so.dSYM

# Generated by roxygen2: do not edit by hand

export(outputs)
export(redatam_close)
export(redatam_entities)
export(redatam_info)
export(redatam_load_plugin)
export(redatam_open)
export(redatam_query)
export(redatam_run)
export(redatam_save)
export(redatam_variables)
export(redatam_version)
exportPattern("^[[:alpha:]]+")
useDynLib(redatamx, .registration = TRUE)

# redatamx

## About

**redatamx** is a package to work with REDATAM databases in RXDB (new) or DICX (old) format.

## Installation

To install the R package, run the following command:

``` r
# Install released version from CRAN
install.packages("redatamx")
```

## Usage

The Redatam package enables the use of REDATAM databases inside R. It is possible to open a REDATAM dictionary (**dicx** format or the new **rxdb** format) and run Redatam programs written in SPC language.

For example:

``` r
library(redatamx)

# open a dictionary
dic<-redatam_open("path/to/nmir.rxdb")

# run a frequency using the new syntax
tbl1<-redatam_query(dic, "freq person.sexo")

#-- you can use the old syntax too
#-- tbl1<-redatam_query(dic, "table t1 as frequency person.sexo")

print(tbl1)

# close the dictionary
redatam_close(dic)
```

> You need to replace `path/to/nmir.rxdb` to point to your NMIR dictionary (Redatam database).

After running the above program, you will find a new data frame *tbl1* that corresponds to the output of the REDATAM program. You can use R commands to operate with the new data frame, the output of the above program is:

```         
##  SEXO1_value SEXO1_label  value
##            1      Hombre  26834
##            2       Mujer  25355
```

## Plugins

You can use custom plugins:

- Datasources: custom formats for database creation
- Exporters: custom formats for exporting the outputs (tables) of SPC queries

You can check the available plugins using `redatam_info()` function:

```         
> redatam_info()
RedEngine 1.0.1-final - <<compiler info>> on 'Apr  3 2025'
  Boost version      : 1_85
  Arrow version      : Compiled with '19.0.1', running on 19.0.1 (1900)
  Parquet version    : Compiled with 'parquet-cpp-arrow version 19.0.1'
  LibXml2 version    : Compiled with '2.13.6'
  Fmt version        : Compiled with '110002'
  OpenSSL version    : Compiled with 'OpenSSL 3.4.1 11 Feb 2025'
Datasources
  CSPRO            CSPRO Redatam datasource
Exporters
  JSON             JSON Redatam exporter (.json files)
  SIDRA            SIDRA Redatam exporter (.sidra files)
  TXT              TEXT Redatam exporter (.txt files)
```

The built-in plugins are: CSPRO, CSV, JSON, SIDRA, TXT.

Third-party plugins available for donwload in the release page.

- CSV, SPSS and STATA datasources
- XLSX exporter

Depending on the operating system, you need to load `.dll` file for windows, `.so` for linux and `.dynlib` for macOS (arm or x86).

```         
redatam_load_plugin('path/to/plugins/datasource-csv.dll')
redatam_load_plugin('path/to/plugins/datasource-spss.dll')
redatam_load_plugin('path/to/plugins/datasource-cspro8.dll')
redatam_load_plugin('path/to/plugins/exporter-xlsx.dll')
```

```         
> redatam_info()
RedEngine 1.1.0-final - <<compiler info>> on 'Apr 27 2025'
  Boost version      : 1_87
  Arrow version      : Compiled with '19.0.1', running on 19.0.1 (1900)
  Parquet version    : Compiled with 'parquet-cpp-arrow version 19.0.1'
  LibXml2 version    : Compiled with '2.13.5'
  Fmt version        : Compiled with '110002'
  OpenSSL version    : Compiled with 'OpenSSL 3.5.0 8 Apr 2025'
Datasources
  CSPRO            CSPRO Redatam datasource
  SPSS             SPSS Redatam datasource
  STATA            STATA Redatam datasource
Exporters
  CSV              CSV Redatam exporter (.csv files)
  JSON             JSON Redatam exporter (.json files)
  SIDRA            SIDRA Redatam exporter (.sidra files)
  TXT              TEXT Redatam exporter (.txt files)
  XLSX             XLSX Redatam exporter (.xlsx files)
```

## Credits

This package was created and is supported by Jaime Salvador ([jaime.salvador\@ideasybits.com](mailto:jaime.salvador@ideasybits.com)) and CELADE ([redatam\@cepal.org](mailto:redatam@cepal.org)).

The REDATAM software is developed by [CELADE](https://redatam.org/) ([redatam\@cepal.org](mailto:redatam@cepal.org)) which is: Copyright (C) 1985-2026, by CELADE, Population Division of ECLAC-United Nations..

.onLoad <- function(libname, pkgname){

  #path to library root
  libRuntimeName = system.file("redengine", "", package = pkgname);

  invisible(.Call(`_redatamx_redatam_init_`, libRuntimeName))

  assign('outputs', new.env(), envir = parent.env(environment()))
}

.onUnload<-function(libpath) {
  invisible(.Call(`_redatamx_redatam_destroy_`))
}

.onAttach<-function(libname, pkgname) {
  packageStartupMessage( paste("Using: ", redatam_version(), "\n") )
}

# Copyright 2024. Jaime Salvador
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of
# this proprietary software and associated documentation files (the "Software"),
# to use, publish, or distribute copies of the Software, and to permit persons to
# whom the Software is furnished to do so.
#
# Any other use, including modifying, adapting, reverse engineering, decompiling,
# or disassembling, is not permitted.
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

#' Environment for Outputs Tables
#'
#' This environment is created to store the outputs generated by a Redatam program
#' execution.
#' The environment contains TABLES (Redatam outputs) generated from FREQ, AREALIST,
#'  MATOP, TABLIST commands.
#' You can't modify objects contained in this environment.
#'
#' @export
#' @examples
#' \dontrun{
#' dic<-redatam_open("path/to/rxdb")
#' df<-redatam_query(dic,"tbl1<-freq person.sexo")
#' # Accessing the tbl1 object from environment
#' redatamx::outputs$tbl1
#' # Accessing the output from Global Environment
#' print(df)
#' }
#'
"outputs"

# Copyright 2024. Jaime Salvador
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of
# this proprietary software and associated documentation files (the "Software"),
# to use, publish, or distribute copies of the Software, and to permit persons to
# whom the Software is furnished to do so.
#
# Any other use, including modifying, adapting, reverse engineering, decompiling,
# or disassembling, is not permitted.
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

#' @title Execute a Redatam command from file
#' @author Jaime Salvador
#' @description Execute a Redatam command: TABLE or AREALIST.
#' This function removes all the rows that contain total, na or mv values. Additionally, this function removes the "mask" columns.
#' @param dic Dictionary identifier
#' @param file_name Program file name
#' @param tot.omit Omit rows containing total, na y mv values
#' @return {
#' If the program contains more than one table, the method returns the last table (in the SPC program) as a data frame.
#' All the tables are registered (as data frames) in a custom environment called \sQuote{redatam::outputs}.
#'}
#' @export
#' @examples
#' \dontrun{
#' dic<-redatam_open("path/to/rxdb")
#' df<-redatam_run(dic,"/path/to/nmir_test.spc")
#' print(df)
#' }

redatam_run<-function( dic, file_name, tot.omit=TRUE ) {

  dfs<-redatam_internal_run( dic, file_name );
  #dfs<-redatam_run( dic, file_name );

  count<-length(dfs)
  index<-0

  for (df in dfs) {

    attrs <- attributes(df)

    dsname<-attr(df,"redatam.table.name")

    attr_type<-attr(df,"redatam.table.type")
    attr_name<-attr(df,"redatam.table.name")
    attr_vars<-attr(df,"redatam.table.vars")

    if( attrs$redatam.table.type=="table"){

      if( tot.omit ){
        cols <- c()

        for (i in 1:length(colnames(df)) ) {
          if( (i %% 3)==0 ) {
            df<-df[df[,i]==0, ]
          }
          else
          {
            cols<-append(cols,i)
          }
        }

        row.names(df)<-c(1:nrow(df))

        df <- df[,cols]

        attr(df,"redatam.table.type")<-attr_type
        attr(df,"redatam.table.name")<-attr_name
        attr(df,"redatam.table.vars")<-attr_vars
      }
    }
    else if(attrs$redatam.table.type=="arealist") {
      # remove empty cols
    }

    #assign( dsname, df, .GlobalEnv )
    assign( dsname, df, envir=outputs )

    if( index==count-1 ) {
      df_last <- df
    }

    index<-index+1
  }

  if(count>0)
    return(df_last)
}

# Copyright 2024. Jaime Salvador
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of
# this proprietary software and associated documentation files (the "Software"),
# to use, publish, or distribute copies of the Software, and to permit persons to
# whom the Software is furnished to do so.
#
# Any other use, including modifying, adapting, reverse engineering, decompiling,
# or disassembling, is not permitted.
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

#' @title Open dictionary
#' @author Jaime Salvador
#' @description Open a REDATAM database.
#' This function returns an ID than can be used in functions to query data.
#' @param dictionary_name Dictionary file name
#' @return ID than can be used in functions to query data.
#' @export
#' @examples
#' \dontrun{
#' dic<-redatam_open("path/to/rxdb")
#' }
redatam_open <- function(dictionary_name) {
  .Call(`_redatamx_redatam_open`, dictionary_name)
}

#' @title Save dictionary
#' @author Jaime Salvador
#' @description Save a REDATAM database.
#' This function  can be used to save a dictionary.
#' @param dic Dictionary identifier (returned by redatam_open())
#' @param name Dictionary file name
#' @return {No return value.}
#' @export
#' @examples
#' \dontrun{
#' dic<-redatam_open("path/to/rxdb")
#' ...
#' redatam_save(dic,"path/to/new/dictionary.rxdb")
#' }
redatam_save <- function(dic, name = "") {
  invisible(.Call(`_redatamx_redatam_save`, dic, name))
}

#' @title Close dictionary
#' @author Jaime Salvador
#' @description Close a REDATAM database.
#' @param dic Dictionary identifier (returned by redatam_open())
#' @return {No return value.}
#' @export
#' @examples
#' \dontrun{
#' dic<-redatam_open("path/to/rxdb")
#' # run some queries using 'redatam_query' or 'redatam_run'
#' # close de dictionary
#' redatam_close(dic);
#' }
redatam_close <- function(dic) {
  invisible(.Call(`_redatamx_redatam_close`, dic))
}

#' @title List entities
#' @author Jaime Salvador
#' @description List the entities in a databse.
#' @param dic Dictionary identifier (returned by redatam_open())
#' @return Data frame that contains all the entities in the database.
#' @export
#' @examples
#' \dontrun{
#' dic<-redatam_open("path/to/rxdb")
#' redatam_entities(dic);
#' }
redatam_entities <- function(dic) {
  .Call(`_redatamx_redatam_entities`, dic)
}

#' @title List variables for entity
#' @author Jaime Salvador
#' @description List the variables in an entity.
#' @param dic Dictionary identifier (returned by redatam_open())
#' @param entity_name Entity's name
#' @return Data frame that contains all the variables from the \sQuote{entity_name}.
#' @export
#' @examples
#' \dontrun{
#' dic<-redatam_open("path/to/rxdb")
#' redatam_variables(dic, "person")
#' }
redatam_variables <- function(dic, entity_name) {
  .Call(`_redatamx_redatam_variables`, dic, entity_name)
}

#' @title Get the Redatam API version
#' @author Jaime Salvador
#' @description Returns the current version of the native Redatam API.
#' @return String with the Redatam Engine version.
#' @export
#' @examples
#' redatam_version()
redatam_version <- function() {
  .Call(`_redatamx_redatam_version`)
}

#' @title Get extended Redatam API information
#' @author Jaime Salvador
#' @description Returns extended information about datasources and datasets available.
#' @return String with the Redatam extended information.
#' @export
#' @examples
#' redatam_info()
redatam_info <- function() {
  cat(.Call(`_redatamx_redatam_info`))
}

#----------------------------------------------------------------------
#' @title Create Redatam database
#' @author Jaime Salvador
#' @description Create a new Redatam database.
#' @param schema_name Dictionary schema in json format
#' @param config_name Configuration in json format
#' @return {No return value.}
#' @examples
#' \dontrun{
#' redatam_create("path/to/schema.json","path/to/config.json")
#' }
redatam_create <- function(schema_name, config_name) {
  invisible(.Call(`_redatamx_redatam_create`, schema_name, config_name))
}

#----------------------------------------------------------------------


#' @title Execute a Redatam command from text
#' @author Jaime Salvador
#' @description Execute a Redatam command: TABLE or AREALIST.
#' @param dic Dictionary identifier (returned by redatam_open())
#' @param spc Program text in SPC format
#' @return Raw dataset with al values: tot, na, mv, values.
#' @keywords internal
#' @examples
#' \dontrun{
#' dic<-redatam_open("path/to/rxdb")
#' df<-redatam_internal_query(dic,"freq person.sexo")
#' }
redatam_internal_query <- function(dic, spc) {
  .Call(`_redatamx_redatam_internal_query`, dic, spc)
}

#' @title Execute a Redatam command from file
#' @author Jaime Salvador
#' @description Execute a Redatam command: TABLE or AREALIST.
#' @param dic Dictionary identifier (returned by redatam_open())
#' @param file_name Program file name
#' @return Raw dataset with all values: tot, na, mv, values.
#' @keywords internal
#' @examples
#' \dontrun{
#' dic<-redatam.open("path/to/rxdb")
#' df<-redatam.internal_run(dic,"/path/to/program.spc")
#' }
redatam_internal_run <- function(dic, file_name) {
  .Call(`_redatamx_redatam_internal_run`, dic, file_name)
}

#' @title Initialize engine
#' @author Jaime Salvador
#' @description Initialize the Redatam engine.
#' This function is automatically called when the package is loaded.
#' @param pachageDir Relative path to Redatam runtime (dll, so or dynlib)
#' @return {No return value.}
#' @keywords internal
#' @examples
#' \dontrun{
#' redatam_init_("/engine");
#' }
redatam_init_ <- function(pachageDir) {
  invisible(.Call(`_redatamx_redatam_init_`, pachageDir))
}

#' @title Destroy engine
#' @author Jaime Salvador
#' @description Destroy the Redatam engine.
#' This function is automatically called when the package is unloaded.
#' @return {No return value.}
#' @keywords internal
#' @examples
#' \dontrun{
#' redatam_destroy_();
#' }
redatam_destroy_ <- function() {
  invisible(.Call(`_redatamx_redatam_destroy_`))
}

# Copyright 2024. Jaime Salvador
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of
# this proprietary software and associated documentation files (the "Software"),
# to use, publish, or distribute copies of the Software, and to permit persons to
# whom the Software is furnished to do so.
#
# Any other use, including modifying, adapting, reverse engineering, decompiling,
# or disassembling, is not permitted.
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

#' @title Load a custom plugin
#' @author Jaime Salvador
#' @description Load a custom plugin into internal registry.
#' This function is used to add a custom plugin that implements a data source
#' (to create database from custom format) or data set (to save outputs in
#' custom format).
#' @param filePath Full path to .dll (windows), .so (linux) or .dynlib (macOs)
#' @return no return.
#' @export
#' @examples
#' \dontrun{
#' redatam_load_plugin("path/to/custom/plugin")
#' }
#'
redatam_load_plugin <- function(filePath) {
  invisible(.Call(`_redatamx_redatam_load_plugin`, filePath))
}

# Generated by cpp11: do not edit by hand

redatam_create <- function(schema_name, config_name) {
  invisible(.Call(`_redatamx_redatam_create`, schema_name, config_name))
}

redatam_open <- function(dictionary_name) {
  .Call(`_redatamx_redatam_open`, dictionary_name)
}

redatam_save <- function(dic, name) {
  invisible(.Call(`_redatamx_redatam_save`, dic, name))
}

redatam_close <- function(dic) {
  invisible(.Call(`_redatamx_redatam_close`, dic))
}

redatam_entities <- function(dic) {
  .Call(`_redatamx_redatam_entities`, dic)
}

redatam_variables <- function(dic, entity_name) {
  .Call(`_redatamx_redatam_variables`, dic, entity_name)
}

redatam_internal_query <- function(dic, spc) {
  .Call(`_redatamx_redatam_internal_query`, dic, spc)
}

redatam_internal_run <- function(dic, file_name) {
  .Call(`_redatamx_redatam_internal_run`, dic, file_name)
}

redatam_version <- function() {
  .Call(`_redatamx_redatam_version`)
}

redatam_info <- function() {
  .Call(`_redatamx_redatam_info`)
}

redatam_init_ <- function(packageDir) {
  invisible(.Call(`_redatamx_redatam_init_`, packageDir))
}

redatam_destroy_ <- function() {
  invisible(.Call(`_redatamx_redatam_destroy_`))
}

redatam_load_plugin <- function(spc) {
  invisible(.Call(`_redatamx_redatam_load_plugin`, spc))
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/redatam-plugins.R
\name{redatam_load_plugin}
\alias{redatam_load_plugin}
\title{Load a custom plugin}
\usage{
redatam_load_plugin(filePath)
}
\arguments{
\item{filePath}{Full path to .dll (windows), .so (linux) or .dynlib (macOs)}
}
\value{
no return.
}
\description{
Load a custom plugin into internal registry.
This function is used to add a custom plugin that implements a data source
(to create database from custom format) or data set (to save outputs in
custom format).
}
\examples{
\dontrun{
redatam_load_plugin("path/to/custom/plugin")
}

}
\author{
Jaime Salvador
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/redatam-api.R
\name{redatam_destroy_}
\alias{redatam_destroy_}
\title{Destroy engine}
\usage{
redatam_destroy_()
}
\value{
{No return value.}
}
\description{
Destroy the Redatam engine.
This function is automatically called when the package is unloaded.
}
\examples{
\dontrun{
redatam_destroy_();
}
}
\author{
Jaime Salvador
}
\keyword{internal}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/redatam-api.R
\name{redatam_variables}
\alias{redatam_variables}
\title{List variables for entity}
\usage{
redatam_variables(dic, entity_name)
}
\arguments{
\item{dic}{Dictionary identifier (returned by redatam_open())}

\item{entity_name}{Entity's name}
}
\value{
Data frame that contains all the variables from the \sQuote{entity_name}.
}
\description{
List the variables in an entity.
}
\examples{
\dontrun{
dic<-redatam_open("path/to/rxdb")
redatam_variables(dic, "person")
}
}
\author{
Jaime Salvador
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/redatam-api.R
\name{redatam_save}
\alias{redatam_save}
\title{Save dictionary}
\usage{
redatam_save(dic, name = "")
}
\arguments{
\item{dic}{Dictionary identifier (returned by redatam_open())}

\item{name}{Dictionary file name}
}
\value{
{No return value.}
}
\description{
Save a REDATAM database.
This function  can be used to save a dictionary.
}
\examples{
\dontrun{
dic<-redatam_open("path/to/rxdb")
...
redatam_save(dic,"path/to/new/dictionary.rxdb")
}
}
\author{
Jaime Salvador
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/redatam-api.R
\name{redatam_info}
\alias{redatam_info}
\title{Get extended Redatam API information}
\usage{
redatam_info()
}
\value{
String with the Redatam extended information.
}
\description{
Returns extended information about datasources and datasets available.
}
\examples{
redatam_info()
}
\author{
Jaime Salvador
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/redatam-api.R
\name{redatam_open}
\alias{redatam_open}
\title{Open dictionary}
\usage{
redatam_open(dictionary_name)
}
\arguments{
\item{dictionary_name}{Dictionary file name}
}
\value{
ID than can be used in functions to query data.
}
\description{
Open a REDATAM database.
This function returns an ID than can be used in functions to query data.
}
\examples{
\dontrun{
dic<-redatam_open("path/to/rxdb")
}
}
\author{
Jaime Salvador
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/redatam-run.R
\name{redatam_run}
\alias{redatam_run}
\title{Execute a Redatam command from file}
\usage{
redatam_run(dic, file_name, tot.omit = TRUE)
}
\arguments{
\item{dic}{Dictionary identifier}

\item{file_name}{Program file name}

\item{tot.omit}{Omit rows containing total, na y mv values}
}
\value{
{
If the program contains more than one table, the method returns the last table (in the SPC program) as a data frame.
All the tables are registered (as data frames) in a custom environment called \sQuote{redatam::outputs}.
}
}
\description{
Execute a Redatam command: TABLE or AREALIST.
This function removes all the rows that contain total, na or mv values. Additionally, this function removes the "mask" columns.
}
\examples{
\dontrun{
dic<-redatam_open("path/to/rxdb")
df<-redatam_run(dic,"/path/to/nmir_test.spc")
print(df)
}
}
\author{
Jaime Salvador
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/redatam-api.R
\name{redatam_close}
\alias{redatam_close}
\title{Close dictionary}
\usage{
redatam_close(dic)
}
\arguments{
\item{dic}{Dictionary identifier (returned by redatam_open())}
}
\value{
{No return value.}
}
\description{
Close a REDATAM database.
}
\examples{
\dontrun{
dic<-redatam_open("path/to/rxdb")
# run some queries using 'redatam_query' or 'redatam_run'
# close de dictionary
redatam_close(dic);
}
}
\author{
Jaime Salvador
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/output-env.R
\docType{data}
\name{outputs}
\alias{outputs}
\title{Environment for Outputs Tables}
\format{
An object of class \code{environment} of length 0.
}
\usage{
outputs
}
\description{
This environment is created to store the outputs generated by a Redatam program
execution.
The environment contains TABLES (Redatam outputs) generated from FREQ, AREALIST,
MATOP, TABLIST commands.
You can't modify objects contained in this environment.
}
\examples{
\dontrun{
dic<-redatam_open("path/to/rxdb")
df<-redatam_query(dic,"tbl1<-freq person.sexo")
# Accessing the tbl1 object from environment
redatamx::outputs$tbl1
# Accessing the output from Global Environment
print(df)
}

}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/redatam-api.R
\name{redatam_internal_run}
\alias{redatam_internal_run}
\title{Execute a Redatam command from file}
\usage{
redatam_internal_run(dic, file_name)
}
\arguments{
\item{dic}{Dictionary identifier (returned by redatam_open())}

\item{file_name}{Program file name}
}
\value{
Raw dataset with all values: tot, na, mv, values.
}
\description{
Execute a Redatam command: TABLE or AREALIST.
}
\examples{
\dontrun{
dic<-redatam.open("path/to/rxdb")
df<-redatam.internal_run(dic,"/path/to/program.spc")
}
}
\author{
Jaime Salvador
}
\keyword{internal}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/redatam-package.R
\docType{package}
\name{redatamx-package}
\alias{redatamx}
\alias{redatamx-package}
\title{redatamx: R Interface to 'Redatam' Library}
\description{
Provides an API to work with 'Redatam' (see \url{https://redatam.org}) databases in both formats: 'RXDB' (new format) and 'DICX' (old format) and running 'Redatam' programs written in 'SPC' language. It's a wrapper around 'Redatam' core and provides functions to open/close a database (redatam_open()/redatam_close()), list entities and variables from the database (redatam_entities(), redatam_variables()) and execute a 'SPC' program and gets the results as data frames (redatam_query(), redatam_run()).
}
\seealso{
Useful links:
\itemize{
  \item \url{https://ideasybits.github.io/redatamx4r/}
  \item \url{https://github.com/ideasybits/redatamx4r/}
  \item Report bugs at \url{https://github.com/ideasybits/redatamx4r/issues}
}

}
\author{
\strong{Maintainer}: Jaime Salvador \email{jaime.salvador@ideasybits.com} (\href{https://orcid.org/0000-0002-3564-8929}{ORCID})

Other contributors:
\itemize{
  \item CELADE [copyright holder]
}

}
\keyword{internal}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/redatam-api.R
\name{redatam_internal_query}
\alias{redatam_internal_query}
\title{Execute a Redatam command from text}
\usage{
redatam_internal_query(dic, spc)
}
\arguments{
\item{dic}{Dictionary identifier (returned by redatam_open())}

\item{spc}{Program text in SPC format}
}
\value{
Raw dataset with al values: tot, na, mv, values.
}
\description{
Execute a Redatam command: TABLE or AREALIST.
}
\examples{
\dontrun{
dic<-redatam_open("path/to/rxdb")
df<-redatam_internal_query(dic,"freq person.sexo")
}
}
\author{
Jaime Salvador
}
\keyword{internal}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/redatam-api.R
\name{redatam_entities}
\alias{redatam_entities}
\title{List entities}
\usage{
redatam_entities(dic)
}
\arguments{
\item{dic}{Dictionary identifier (returned by redatam_open())}
}
\value{
Data frame that contains all the entities in the database.
}
\description{
List the entities in a databse.
}
\examples{
\dontrun{
dic<-redatam_open("path/to/rxdb")
redatam_entities(dic);
}
}
\author{
Jaime Salvador
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/redatam-api.R
\name{redatam_create}
\alias{redatam_create}
\title{Create Redatam database}
\usage{
redatam_create(schema_name, config_name)
}
\arguments{
\item{schema_name}{Dictionary schema in json format}

\item{config_name}{Configuration in json format}
}
\value{
{No return value.}
}
\description{
Create a new Redatam database.
}
\examples{
\dontrun{
redatam_create("path/to/schema.json","path/to/config.json")
}
}
\author{
Jaime Salvador
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/redatam-api.R
\name{redatam_version}
\alias{redatam_version}
\title{Get the Redatam API version}
\usage{
redatam_version()
}
\value{
String with the Redatam Engine version.
}
\description{
Returns the current version of the native Redatam API.
}
\examples{
redatam_version()
}
\author{
Jaime Salvador
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/redatam-api.R
\name{redatam_init_}
\alias{redatam_init_}
\title{Initialize engine}
\usage{
redatam_init_(pachageDir)
}
\arguments{
\item{pachageDir}{Relative path to Redatam runtime (dll, so or dynlib)}
}
\value{
{No return value.}
}
\description{
Initialize the Redatam engine.
This function is automatically called when the package is loaded.
}
\examples{
\dontrun{
redatam_init_("/engine");
}
}
\author{
Jaime Salvador
}
\keyword{internal}
